@@ -1,9 +1,10 @@
 from .webdriver import (
     chrome_driver,
-    force_refresh_webpage, wait_and_click_element
+    force_refresh_webpage, wait_and_click_element,
 )
 from .distributed import (
     PLUGIN_DIR, NSFW_TAGS,
     T_UserID, T_AuthorizedUserID, T_GroupID, T_AuthorizedGroupID,
-    get_mac_address, convert_audio2wav
+    get_mac_address, convert_audio2wav,
+    fetch_image_in_message, inject_image_to_state
 )
